<?php

namespace Litepci\Category\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Category\Models\Subcategory;

class SubcategoryPolicy
{

    /**
     * Determine if the given user can view the subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subcategory $subcategory)
    {
        if ($user->canDo('category.subcategory.view') && $user->isAdmin()) {
            return true;
        }

        return $subcategory->user_id == user_id() && $subcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('category.subcategory.create');
    }

    /**
     * Determine if the given user can update the given subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subcategory $subcategory)
    {
        if ($user->canDo('category.subcategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $subcategory->user_id == user_id() && $subcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subcategory $subcategory)
    {
        return $subcategory->user_id == user_id() && $subcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subcategory $subcategory)
    {
        if ($user->canDo('category.subcategory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subcategory.
     *
     * @param UserPolicy $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subcategory $subcategory)
    {
        if ($user->canDo('category.subcategory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
