<?php

namespace Litepci\Category\Providers;

use Illuminate\Support\ServiceProvider;

class CategoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'category');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'category');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litepci.category', function ($app) {
            return $this->app->make('Litepci\Category\Category');
        });

        // Bind Course to repository
        $this->app->bind(
            'Litepci\Category\Interfaces\CourseRepositoryInterface',
            \Litepci\Category\Repositories\Eloquent\CourseRepository::class
        );
        // Bind Subcategory to repository
        $this->app->bind(
            'Litepci\Category\Interfaces\SubcategoryRepositoryInterface',
            \Litepci\Category\Repositories\Eloquent\SubcategoryRepository::class
        );

        $this->app->register(\Litepci\Category\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Category\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.category'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/category.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/category')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/category')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
